==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/HeaderSeparatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DefinitionBaseDescriptionMetadata } from "./DefinitionBaseDescriptionMetadata";
import { HeaderSeparatorDescription } from "./HeaderSeparatorDescription";
/**
 * @hidden
 */
var HeaderSeparatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(HeaderSeparatorDescriptionMetadata, _super);
    function HeaderSeparatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    HeaderSeparatorDescriptionMetadata.b = function (a) {
        if (HeaderSeparatorDescriptionMetadata.a == null) {
            HeaderSeparatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            HeaderSeparatorDescriptionMetadata.c(HeaderSeparatorDescriptionMetadata.a);
        }
        if (a.j(HeaderSeparatorDescriptionMetadata.a)) {
            return;
        }
        a.y(HeaderSeparatorDescriptionMetadata.a);
    };
    HeaderSeparatorDescriptionMetadata.c = function (a) {
        DefinitionBaseDescriptionMetadata.c(a);
    };
    HeaderSeparatorDescriptionMetadata.d = function (a) {
        HeaderSeparatorDescriptionMetadata.b(a);
        a.aa("HeaderSeparator", function () { return new HeaderSeparatorDescription(); });
        a.z("HeaderSeparator", HeaderSeparatorDescriptionMetadata.a);
    };
    HeaderSeparatorDescriptionMetadata.$t = markType(HeaderSeparatorDescriptionMetadata, 'HeaderSeparatorDescriptionMetadata');
    HeaderSeparatorDescriptionMetadata.a = null;
    return HeaderSeparatorDescriptionMetadata;
}(Base));
export { HeaderSeparatorDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/HeaderSeparatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DefinitionBaseDescriptionMetadata } from "./DefinitionBaseDescriptionMetadata";
import { HeaderSeparatorDescription } from "./HeaderSeparatorDescription";
/**
 * @hidden
 */
var HeaderSeparatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(HeaderSeparatorDescriptionMetadata, _super);
    function HeaderSeparatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    HeaderSeparatorDescriptionMetadata.b = function (a) {
        if (HeaderSeparatorDescriptionMetadata.a == null) {
            HeaderSeparatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            HeaderSeparatorDescriptionMetadata.c(HeaderSeparatorDescriptionMetadata.a);
        }
        if (a.k(HeaderSeparatorDescriptionMetadata.a)) {
            return;
        }
        a.aa(HeaderSeparatorDescriptionMetadata.a);
    };
    HeaderSeparatorDescriptionMetadata.c = function (a) {
        DefinitionBaseDescriptionMetadata.c(a);
    };
    HeaderSeparatorDescriptionMetadata.d = function (a) {
        HeaderSeparatorDescriptionMetadata.b(a);
        a.ac("HeaderSeparator", function () { return new HeaderSeparatorDescription(); });
        a.ab("HeaderSeparator", HeaderSeparatorDescriptionMetadata.a);
    };
    HeaderSeparatorDescriptionMetadata.$t = markType(HeaderSeparatorDescriptionMetadata, 'HeaderSeparatorDescriptionMetadata');
    HeaderSeparatorDescriptionMetadata.a = null;
    return HeaderSeparatorDescriptionMetadata;
}(Base));
export { HeaderSeparatorDescriptionMetadata };
